============
Contributing
============

Contributions are welcome, and they are greatly appreciated! Every
little bit helps, and credit will always be given.

.. toctree::
    :numbered:
    :maxdepth: 2

    contributor_types
    contributor_setup
    contributor_guidelines
